==> turbina-2.05.tgz: turbina-2.05/src/names.h <==
/*--------------------------------------------------------------------------*/
/** @file names.h
@brief  Reserved string constants: file names, paths, extentions and the numeric
 formats for data display on the screen.
 
Note that the formats of data which are stored in the mass-file are defined in 
scientific modules of TURBINA.


 @author O. Voziakova, Sternberg Institute (ovoz@sai.msu.ru)
 
 @version 1.0
*/
#ifndef NAMES_H
#define NAMES_H

#define VERSION			"2.048"

#define devFileName		"/dev/mcua0"
#define	cfgFile			"/opt/turbina/etc/turbina.cfg"
#define deviceCfgFile		"/opt/turbina/etc/device.cfg"
#define cfgStatusFile		"/opt/turbina/etc/status.dat"
#define	dataPath		"/opt/turbina/data/"
#define helpFile		"/opt/turbina/doc/help.txt"
#define massRootGroupName	"root"
#define massUserGroupName	"users"
#define	indexFileExt		"mass"
#define	pbInFileExt		"mass.in"
#define	pbOutFileExt		"mass.out"
#define	logFileExt		"log"
#define	countsFileExt		"cnt"
#define	momentsFileExt		"stm"
#define	wfFileExt		"wf"
#define	sedFileExt		"sp"
#define lutFileExt		"lut"
#define checkFileName		"atmos.tmp"
#define summaryFile		"summary.mass"
#define dumpFile		"dump.bin"

#define lightFormat	"%4.2f"
#define hvFormat	"%4d"
#define levFormat	"%3.1f"
#define fluxFormat	"%#6.4g"
#define errFormat	"%.3f"
#define poisFormat	"%5.3f"
#define SIFormat	"%6.4f"
#define seeFormat	"%5.2f"
#define heffFormat	"%5.0f"
#define isoplFormat	"%5.2f"
#define m2Format	"%5.2f"
#define m0Format	"%5.2f"
#define tauFormat	"%5.2f"
#define zFormat		"%4.1f"
#define cn2Format	"%.2f"
#define chi2Format	"%6.2f"
#define orderFormat	"%3d"
#define cxFormat	"%.2f"
#define shiftFormat	"%.2f"


#define ON			1
#define OFF			0
#define OPEN		1
#define CLOSE		0
#define YES			1
#define NO			0
#define UNDEFINED	-1
#define RA			0
#define DECLINATION	1

#define APERTURE_SHIFT_METHOD	0
#define TELESCOPE_SHIFT_METHOD	1
#define EXTERNAL_TELESCOPE_SHIFT_METHOD	2

#define NCONST	4
#define NIDENT	4

#define NO_DEVICE	"No LPT converter or MOXA102 detected!"

#endif

==> turbina-2.048.tgz: turbina-2.048/src/names.h <==
/*--------------------------------------------------------------------------*/
/** @file names.h
@brief  Reserved string constants: file names, paths, extentions and the numeric
 formats for data display on the screen.
 
Note that the formats of data which are stored in the mass-file are defined in 
scientific modules of TURBINA.


 @author O. Voziakova, Sternberg Institute (ovoz@sai.msu.ru)
 
 @version 1.0
*/
#ifndef NAMES_H
#define NAMES_H

#define VERSION			"2.048"

#define devFileName		"/dev/mcua0"
#define	cfgFile			"/usr/share/turbina/config/turbina.cfg"
#define deviceCfgFile		"/usr/share/turbina/config/device.cfg"
#define cfgStatusFile		"/usr/share/turbina/config/status.dat"
#define	dataPath		"/usr/share/turbina/"
#define helpFile		"/usr/share/doc/turbina/help.txt"
#define massRootGroupName	"root"
#define massUserGroupName	"users"
#define	indexFileExt		"mass"
#define	pbInFileExt		"mass.in"
#define	pbOutFileExt		"mass.out"
#define	logFileExt		"log"
#define	countsFileExt		"cnt"
#define	momentsFileExt		"stm"
#define	wfFileExt		"wf"
#define	sedFileExt		"sp"
#define lutFileExt		"lut"
#define checkFileName		"atmos.tmp"
#define summaryFile		"summary.mass"
#define dumpFile		"dump.bin"

#define lightFormat	"%4.2f"
#define hvFormat	"%4d"
#define levFormat	"%3.1f"
#define fluxFormat	"%#6.4g"
#define errFormat	"%.3f"
#define poisFormat	"%5.3f"
#define SIFormat	"%6.4f"
#define seeFormat	"%5.2f"
#define heffFormat	"%5.0f"
#define isoplFormat	"%5.2f"
#define m2Format	"%5.2f"
#define m0Format	"%5.2f"
#define tauFormat	"%5.2f"
#define zFormat		"%4.1f"
#define cn2Format	"%.2f"
#define chi2Format	"%6.2f"
#define orderFormat	"%3d"
#define cxFormat	"%.2f"
#define shiftFormat	"%.2f"


#define ON			1
#define OFF			0
#define OPEN		1
#define CLOSE		0
#define YES			1
#define NO			0
#define UNDEFINED	-1
#define RA			0
#define DECLINATION	1

#define APERTURE_SHIFT_METHOD	0
#define TELESCOPE_SHIFT_METHOD	1
#define EXTERNAL_TELESCOPE_SHIFT_METHOD	2

#define NCONST	4
#define NIDENT	4

#define NO_DEVICE	"No LPT converter or MOXA102 detected!"

#endif
